# Blackjack Game

A Python-based blackjack game (heavily inspired by Resident Evil 7, 21 DLC). This project was built with the goal of following the procedural programming paradigm that I am studying at university.
Enter the command 'blackjack' in a terminal to run the game.

---
## Features
- **Functional blackjack game:** Play a game of blackjack, where the first to win 3 rounds is the winner.
- **Trump cards:** Use special cards to help you gain an advantage over your opponent.
- **Player Stats:** Tracks wins and losses over multiple rounds.
- **Logic-based Dealer:** Play against an intelligent opponent.
---

